@@ -1,7 +1,6 @@
 #' Create package pdf manual
 #'
-#' @param pkg package description, can be path or package name.  See
-#'   [as.package()] for more information.
+#' @template devtools
 #' @param path path in which to produce package manual.
 #'   If `NULL`, defaults to the parent directory of the package.
 #'
@@ -9,16 +8,16 @@
 #' @export
 build_manual <- function(pkg = ".", path = NULL) {
   pkg <- as.package(pkg)
-  path <- path %||% dirname(pkg$path)
+  path <- path %||% path_dir(pkg$path)
   name <- paste0(pkg$package, "_", pkg$version, ".pdf", collapse = " ")
   tryCatch(msg <- callr::rcmd("Rd2pdf", cmdargs = c(
     "--force",
     paste0("--output=", path, "/", name),
     pkg$path
-  ), fail_on_status = TRUE),
+  ), fail_on_status = TRUE, stderr = "2>&1", spinner = FALSE),
   error = function(e) {
-    cat(e$stderr)
-    stop("Failed to build manual", call. = FALSE)
+    cat(e$stdout)
+    cli::cli_abort("Failed to build manual")
   })
 
   cat(msg$stdout)
