@@ -26,6 +26,13 @@
 #'   binary artefacts (like \file{.o}, `.so`) from appearing in your local
 #'   package directory, but is considerably slower, because every compile has
 #'   to start from scratch.
+#'
+#'   One downside of installing from a built tarball is that the package is
+#'   installed from a temporary location. This means that any source references,
+#'   at R level or C/C++ level, will point to dangling locations. The debuggers
+#'   will not be able to find the sources for step-debugging. If you're
+#'   installing the package for development, consider setting `build` to
+#'   `FALSE`.
 #' @param args An optional character vector of additional command line
 #'   arguments to be passed to `R CMD INSTALL`. This defaults to the
 #'   value of the option `"devtools.install.args"`.
@@ -46,7 +53,7 @@
 install <-
   function(pkg = ".", reload = TRUE, quick = FALSE, build = !quick,
              args = getOption("devtools.install.args"), quiet = FALSE,
-             dependencies = NA, upgrade = "ask",
+             dependencies = NA, upgrade = "default",
              build_vignettes = FALSE,
              keep_source = getOption("keep.source.pkgs"),
              force = FALSE,
@@ -56,11 +63,13 @@ install <-
     # Forcing all of the promises for the current namespace now will avoid lazy-load
     # errors when the new package is installed overtop the old one.
     # https://stat.ethz.ch/pipermail/r-devel/2015-December/072150.html
-    if (is_loaded(pkg)) {
+    if (reload && is_loaded(pkg)) {
       eapply(pkgload::ns_env(pkg$package), force, all.names = TRUE)
     }
 
     if (isTRUE(build_vignettes)) {
+      # we likely need all Suggested dependencies if building vignettes
+      dependencies <- TRUE
       build_opts <- c("--no-resave-data", "--no-manual")
     } else {
       build_opts <- c("--no-resave-data", "--no-manual", "--no-build-vignettes")
@@ -85,7 +94,7 @@ install <-
 
     if (build) {
       install_path <- pkgbuild::build(pkg$path, dest_path = tempdir(), args = build_opts, quiet = quiet)
-      on.exit(unlink(install_path), add = TRUE)
+      on.exit(file_delete(install_path), add = TRUE)
     } else {
       install_path <- pkg$path
     }
@@ -93,12 +102,12 @@ install <-
     was_loaded <- is_loaded(pkg)
     was_attached <- is_attached(pkg)
 
-    if (was_loaded) {
-      pkgload::unload(pkg$package)
+    if (reload && was_loaded) {
+      pkgload::unregister(pkg$package)
     }
 
     pkgbuild::with_build_tools(required = FALSE,
-      callr::rcmd("INSTALL", c(install_path, opts), echo = !quiet, show = !quiet, fail_on_status = TRUE)
+      callr::rcmd("INSTALL", c(install_path, opts), echo = !quiet, show = !quiet, spinner = FALSE, stderr = "2>&1", fail_on_status = TRUE)
     )
 
     if (reload && was_loaded) {
@@ -175,3 +184,11 @@ install_dev_deps <- function(pkg = ".",
     ...
   )
 }
+
+local_install <- function(pkg = ".", quiet = TRUE, env = parent.frame()) {
+  pkg <- as.package(pkg)
+
+  cli::cli_inform(c(i = "Installing {.pkg {pkg$package}} in temporary library"))
+  withr::local_temp_libpaths(.local_envir = env)
+  install(pkg, upgrade = "never", reload = FALSE, quick = TRUE, quiet = quiet)
+}
