@@ -1,6 +1,15 @@
+test_that("find_active_file() gives useful error if no RStudio", {
+  expect_snapshot(find_active_file(), error = TRUE)
+})
+
 test_that("fails if can't find tests", {
-  expect_error(find_test_file("DESCRIPTION"), "find tests")
-  expect_error(find_test_file("R/foo.R"), "No test files found")
+  dir <- local_package_create()
+  withr::local_dir(dir)
+
+  expect_snapshot(error = TRUE, {
+    find_test_file("R/foo.blah")
+    find_test_file("R/foo.R")
+  })
 })
 
 test_that("can determine file type", {
