@@ -1,3 +1,3 @@
 test_that("warning from test", {
-  warning("Beware!")
+  warning("Beware!") # nolint
 })
